@@ -1,6 +1,7 @@
 from abc import abstractmethod
 from pathlib import Path
 from typing import Any, List, Type
+from orionis.console.base.scheduler import BaseScheduler
 from orionis.foundation.config.roots.paths import Paths
 from orionis.container.contracts.service_provider import IServiceProvider
 from orionis.container.contracts.container import IContainer
@@ -92,6 +93,65 @@ class IApplication(IContainer):
         """
         pass
 
+    @abstractmethod
+    def setScheduler(
+        self,
+        scheduler: BaseScheduler
+    ) -> 'IApplication':
+        """
+        Register a custom scheduler class for the application.
+
+        This method allows you to specify a custom scheduler class that inherits from
+        `BaseScheduler`. The scheduler is responsible for managing scheduled tasks
+        within the application. The provided class will be validated to ensure it is
+        a subclass of `BaseScheduler` and then stored for later use.
+
+        Parameters
+        ----------
+        scheduler : Type[BaseScheduler]
+            The scheduler class to be used by the application. Must inherit from
+            `BaseScheduler`.
+
+        Returns
+        -------
+        Application
+            Returns the current `Application` instance to enable method chaining.
+
+        Raises
+        ------
+        OrionisTypeError
+            If the provided scheduler is not a subclass of `BaseScheduler`.
+
+        Notes
+        -----
+        The scheduler class is stored internally and can be used by the application
+        to manage scheduled jobs or tasks. This method does not instantiate the
+        scheduler; it only registers the class for later use.
+        """
+        pass
+
+    @abstractmethod
+    def getScheduler(
+        self
+    ) -> BaseScheduler:
+        """
+        Retrieve the currently registered scheduler instance.
+
+        This method returns the scheduler instance that has been set using the
+        `setScheduler` method. If no scheduler has been set, it raises an error.
+
+        Returns
+        -------
+        BaseScheduler
+            The currently registered scheduler instance.
+
+        Raises
+        ------
+        OrionisRuntimeError
+            If no scheduler has been set in the application.
+        """
+        pass
+
     @abstractmethod
     def withConfigurators(
         self,
@@ -705,7 +765,7 @@ class IApplication(IContainer):
         pass
 
     @abstractmethod
-    def path(self, key: str = None, default: Any = None) -> Any:
+    def path(self, key: str = None, default: Any = None) -> str:
         """
         Retrieve path configuration values using dot notation access.
 
@@ -723,7 +783,7 @@ class IApplication(IContainer):
 
         Returns
         -------
-        Any
+        str
             The path value associated with the key, the entire paths configuration
             object if no key is provided, or the default value if the key is not found.
         """
