@@ -53,7 +53,7 @@ class TestFoundationConfigRootPaths(AsyncTestCase):
         None
         """
         with self.assertRaises(OrionisIntegrityException):
-            Paths(console_scheduler=123)
+            Paths(commands=123)
 
     def testToDictReturnsCompleteDictionary(self):
         """
