@@ -948,14 +948,5 @@ class TestServiceReflectionConcrete(AsyncTestCase):
         """
         reflect = ReflectionConcrete(FakeClass)
         method_deps: ResolveArguments = reflect.getMethodDependencies('instanceSyncMethod')
-        self.assertIn('x', method_deps.resolved)
-        self.assertIn('y', method_deps.resolved)
-        self.assertEqual(method_deps.resolved['x'].class_name, 'int')
-        self.assertEqual(method_deps.resolved['y'].class_name, 'int')
-        self.assertEqual(method_deps.resolved['x'].module_name, 'builtins')
-        self.assertEqual(method_deps.resolved['y'].module_name, 'builtins')
-        self.assertEqual(method_deps.resolved['x'].type, int)
-        self.assertEqual(method_deps.resolved['y'].type, int)
-        self.assertEqual(method_deps.resolved['x'].full_class_path, 'builtins.int')
-        self.assertEqual(method_deps.resolved['y'].full_class_path, 'builtins.int')
-        self.assertEqual(method_deps.unresolved, [])
+        self.assertIn('x', method_deps.unresolved)
+        self.assertIn('y', method_deps.unresolved)
